@@ -1,6 +1,6 @@
 from typing import Dict, List, Optional
 
-from pydantic import BaseModel
+from lago_python_client.base_model import BaseModel
 
 from ..base_model import BaseResponseModel
 
