@@ -1,6 +1,6 @@
 from typing import List, Optional
 
-from pydantic import BaseModel
+from lago_python_client.base_model import BaseModel
 
 from .credit import CreditsResponse
 from .customer import CustomerResponse
@@ -25,6 +25,7 @@ class InvoiceFee(BaseModel):
     unit_amount_cents: Optional[int]
     units: Optional[float]
     description: Optional[str]
+    invoice_display_name: Optional[str]
     tax_codes: Optional[List[str]]
 
 
